var searchData=
[
  ['jxlanimationheader_0',['JxlAnimationHeader',['../structJxlAnimationHeader.html',1,'']]],
  ['jxlbasicinfo_1',['JxlBasicInfo',['../structJxlBasicInfo.html',1,'']]],
  ['jxlbitdepth_2',['JxlBitDepth',['../structJxlBitDepth.html',1,'']]],
  ['jxlblendinfo_3',['JxlBlendInfo',['../structJxlBlendInfo.html',1,'']]],
  ['jxlchunkedframeinputsource_4',['JxlChunkedFrameInputSource',['../structJxlChunkedFrameInputSource.html',1,'']]],
  ['jxlcmsinterface_5',['JxlCmsInterface',['../structJxlCmsInterface.html',1,'']]],
  ['jxlcolorencoding_6',['JxlColorEncoding',['../structJxlColorEncoding.html',1,'']]],
  ['jxlcolorprofile_7',['JxlColorProfile',['../structJxlColorProfile.html',1,'']]],
  ['jxldecoderdestroystruct_8',['JxlDecoderDestroyStruct',['../structJxlDecoderDestroyStruct.html',1,'']]],
  ['jxlencoderdestroystruct_9',['JxlEncoderDestroyStruct',['../structJxlEncoderDestroyStruct.html',1,'']]],
  ['jxlencoderoutputprocessor_10',['JxlEncoderOutputProcessor',['../structJxlEncoderOutputProcessor.html',1,'']]],
  ['jxlextrachannelinfo_11',['JxlExtraChannelInfo',['../structJxlExtraChannelInfo.html',1,'']]],
  ['jxlframeheader_12',['JxlFrameHeader',['../structJxlFrameHeader.html',1,'']]],
  ['jxlheaderextensions_13',['JxlHeaderExtensions',['../structJxlHeaderExtensions.html',1,'']]],
  ['jxllayerinfo_14',['JxlLayerInfo',['../structJxlLayerInfo.html',1,'']]],
  ['jxlmemorymanagerstruct_15',['JxlMemoryManagerStruct',['../structJxlMemoryManagerStruct.html',1,'']]],
  ['jxlpixelformat_16',['JxlPixelFormat',['../structJxlPixelFormat.html',1,'']]],
  ['jxlpreviewheader_17',['JxlPreviewHeader',['../structJxlPreviewHeader.html',1,'']]],
  ['jxlresizableparallelrunnerdestroystruct_18',['JxlResizableParallelRunnerDestroyStruct',['../structJxlResizableParallelRunnerDestroyStruct.html',1,'']]],
  ['jxlthreadparallelrunnerdestroystruct_19',['JxlThreadParallelRunnerDestroyStruct',['../structJxlThreadParallelRunnerDestroyStruct.html',1,'']]]
];
